==> mozilla_0.9.9.orig.tar.gz: mozilla/embedding/qa/testembed/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by testembed.rc
//
#define IDD_ABOUTBOX                    100
#define IDR_MAINFRAME                   128
#define IDR_MOZEMBTYPE                  129
#define IDR_CTXMENU_DOCUMENT            130
#define IDR_CTXMENU_LINK                131
#define IDR_CTXMENU_TEXT                132
#define IDR_CTXMENU_IMAGE               133
#define IDD_PROMPT_DIALOG               134
#define IDD_PROMPT_PASSWORD_DIALOG      135
#define IDD_PROMPT_USERPASS_DIALOG      136
#define IDD_PROFILES                    137
#define IDD_PROFILE_NEW                 138
#define IDD_PROFILE_RENAME              139
#define IDD_FINDDLG                     140
#define IDD_PRINT_PROGRESS_DIALOG       141
#define IDD_PREFS_START_PAGE            142
#define IDD_URLDIALOG                   144
#define IDD_DIALOG1                     145
#define IDD_RUNTESTSDLG                 145
#define ID_URL_BAR                      1001
#define ID_PROG_BAR                     1002
#define IDC_PROMPT_ANSWER               1003
#define IDC_PROMPT_QUESTION             1004
#define IDC_PROMPT_TEXT                 1005
#define IDC_USERNAME                    1006
#define IDC_PASSWORD                    1007
#define IDC_CHECK_SAVE_PASSWORD         1008
#define IDC_USERNAME_LABEL              1009
#define IDC_PASSWORD_LABEL              1010
#define IDC_LIST1                       1011
#define IDC_PROF_RENAME                 1012
#define IDC_PROF_DELETE                 1013
#define IDC_PROF_NEW                    1014
#define IDC_CHECK_ASK_AT_START          1015
#define IDC_NEW_PROF_NAME               1016
#define IDC_LOCALE_COMBO                1017
#define IDC_NEW_NAME                    1018
#define IDC_PPD_DOC_TXT                 1020
#define IDC_PPD_DOC_TITLE_STATIC        1021
#define IDC_ENTER_URLTEXT               1022
#define IDC_URLFIELD                    1023
#define IDC_MATCH_WHOLE_WORD            1040
#define IDC_MATCH_CASE                  1041
#define IDC_WRAP_AROUND                 1042
#define IDC_SEARCH_BACKWARDS            1043
#define IDC_FIND_EDIT                   1152
#define IDC_RADIO_BLANK_PAGE            1153
#define IDC_RADIO_HOME_PAGE             1154
#define IDC_EDIT_HOMEPAGE               1155
#define ID_NAV_BACK                     32773
#define ID_NAV_FORWARD                  32774
#define ID_NAV_HOME                     32775
#define ID_NAV_STOP                     32776
#define ID_NAV_RELOAD                   32777
#define ID_EDIT_SELECT_NONE             32778
#define ID_NEW_BROWSER                  32779
#define ID_VIEW_SOURCE                  32780
#define ID_VIEW_INFO                    32781
#define ID_VIEW_IMAGE                   32782
#define ID_OPEN_LINK_IN_NEW_WINDOW      32783
#define ID_SAVE_LINK_AS                 32784
#define ID_SAVE_IMAGE_AS                32785
#define ID_COPY_LINK_LOCATION           32786
#define ID_MANAGE_PROFILES              32787
#define ID_EDIT_PREFERENCES             32788
#define ID_TESTS_CHANGEURL              32789
#define ID_TESTS_GLOBALHISTORY          32790
#define ID_TOOLS_REMOVEGHPAGE           32791
#define ID_TESTS_CREATEFILE             32792
#define ID_INTERFACES_NSIFILE           32793
#define ID_TESTS_CREATEPROFILE          32794
#define ID_INTERFACES_NSISHISTORY       32795
#define ID_VERIFYBUGS_70228             32796
#define ID_TOOLS_REMOVEALLGH            32797
#define ID_TESTS_ADDWEBPROGLISTENER     32798
#define ID_TESTS_ADDHISTORYLISTENER     32799
#define ID_INTERFACES_NSIWEBNAV         32800
#define ID_TOOLS_TESTYOURMETHOD         32801
#define ID_TOOLS_TESTYOURMETHOD2        32802
#define ID_INTERFACES_NSIREQUEST        32803
#define ID_INTERFACES_TEMP              32804
#define ID_INTERFACES_NSIDOMWINDOW_RUNALLTESTS 32808
#define ID_INTERFACES_NSIDOMWINDOW_GETDOMDOCUMENT 32809
#define ID_INTERFACES_NSIDOMWINDOW_GETPARENT 32810
#define ID_INTERFACES_NSIDOMWINDOW_GETSCROLLBARS 32811
#define ID_INTERFACES_NSIDOMWINDOW_GETFRAMES 32812
#define ID_INTERFACES_NSIDOMWINDOW_GETNAME 32813
#define ID_INTERFACES_NSIDOMWINDOW_GETSCSOLLX 32814
#define ID_INTERFACES_NSIDOMWINDOW_GETSCROLLY 32815
#define ID_INTERFACES_NSIDOMWINDOW_SCROLLTO 32816
#define ID_INTERFACES_NSIDOMWINDOW_SCROLLBY 32817
#define ID_INTERFACES_NSIDOMWINDOW_GETSELECTION 32818
#define ID_INTERFACES_NSIDOMWINDOW_SCROLLBYLINES 32819
#define ID_INTERFACES_NSIDOMWINDOW_SCROLLBYPAGES 32820
#define ID_INTERFACES_NSIDOMWINDOW_SIZETOCONTENT 32821
#define ID_INTERFACES_NSIDIRECTORYSERVICE_RUNALLTESTS 32826
#define ID_INTERFACES_NSIDIRECTORYSERVICE_INIT 32827
#define ID_INTERFACES_NSIDIRECTORYSERVICE_REGISTERPROVIDER 32828
#define ID_INTERFACES_NSIDIRECTORYSERVICE_UNREGISTERPROVIDER 32829
#define ID_INTERFACES_NSISELECTION_RUNALLTESTS 32832
#define ID_VERIFYBUGS_90195             32833
#define ID_INTERFACES_CALLBACKS_NSISTREAMLISTENER 32834
#define ID_INTERFACES_CALLBACKS_NSIREQUESTOBSERVER 32835
#define ID_INTERFACES_CALLBACKS_NSISTREAMOBSERVER 32836
#define ID_INTERFACES_NSISELECTION_GETANCHORNODE 32837
#define ID_INTERFACES_NSISELECTION_GETANCHOROFFSET 32838
#define ID_INTERFACES_NSISELECTION_GETFOCUSNODE 32839
#define ID_INTERFACES_NSISELECTION_GETFOCUSOFFSET 32840
#define ID_INTERFACES_NSISELECTION_GETISCOLLAPSED 32841
#define ID_INTERFACES_NSISELECTION_GETRANGECOUNT 32842
#define ID_INTERFACES_NSISELECTION_GETRANGEAT 32843
#define ID_INTERFACES_NSISELECTION_COLLAPSE 32844
#define ID_INTERFACES_NSISELECTION_EXTEND 32845
#define ID_INTERFACES_NSISELECTION_COLLAPSETOSTART 32846
#define ID_INTERFACES_NSISELECTION_COLLAPSETOEND 32847
#define ID_INTERFACES_NSISELECTION_CONTAINSNODE 32848
#define ID_INTERFACES_NSISELECTION_SELECTALLCHILDREN 32849
#define ID_INTERFACES_NSISELECTION_ADDRANGE 32850
#define ID_INTERFACES_NSISELECTION_REMOVERANGE 32851
#define ID_INTERFACES_NSISELECTION_REMOVEALLRANGES 32852
#define ID_INTERFACES_NSISELECTION_DELETEFROMDOCUMENT 32853
#define ID_INTERFACES_NSISELECTION_SELECTIONLANGUAGECHANGE 32854
#define ID_INTERFACES_NSISELECTION_TOSTRING 32855
#define ID_INTERFACES_NSISELECTION_A    32857
#define ID_INTERFACES_NSIPROFILE_RUNALLTESTS 32858
#define ID_INTERFACES_NSIPROFILE_GETPROFILECOUNT 32859
#define ID_INTERFACES_NSIPROFILE_GETCURRENTPROFILE 32860
#define ID_INTERFACES_NSIPROFILE_SETCURRENTPROFILE 32861
#define ID_INTERFACES_NSIPROFILE_GETPROFILELIST 32862
#define ID_INTERFACES_NSIPROFILE_PROFILEEXISTS 32863
#define ID_INTERFACES_NSIPROFILE_CREATENEWPROFILE 32864
#define ID_INTERFACES_NSIPROFILE_RENAMEPROFILE 32865
#define ID_INTERFACES_NSIPROFILE_DELETEPROFILE 32866
#define ID_INTERFACES_NSIPROFILE_CLONEPROFILE 32867
#define ID_INTERFACES_NSIPROFILE_SHUTDOWNCURRENTPROFILE 32868
#define ID_INTERFACES_NSISHISTORY_GETCOUNT 32870
#define ID_INTERFACES_NSISHISTORY_GETINDEX 32871
#define ID_INTERFACES_NSISHISTORY_GETMAXLENGTH 32872
#define ID_INTERFACES_NSISHISTORY_SETMAXLENGTH 32873
#define ID_INTERFACES_NSISHISTORY_GETENTRYATINDEX 32874
#define ID_INTERFACES_NSISHISTORY_PURGEHISTORY 32875
#define ID_INTERFACES_NSISHISTORY_GETSHISTORYENUMERATOR 32878
#define ID_INTERFACES_NSISHISTORY_RUNALLTESTS 32879
#define ID_TESTS_REMOVEHISTORYLISTENER  32880
#define ID_INTERFACES_NSISHISTORY_NSIHISTORYENTRY_RUNALLTESTS 32881
#define ID_INTERFACES_NSISHISTORY_NSIHISTORYENTRY_GETURI 32882
#define ID_INTERFACES_NSISHISTORY_NSIHISTORYENTRY_GETTITLE 32883
#define ID_INTERFACES_NSISHISTORY_NSIHISTORYENTRY_GETISSUBFRAME 32884
#define ID_INTERFACES_NSIREQUEST_GETNAME 32885
#define ID_INTERFACES_NSIREQUEST_ISPENDING 32886
#define ID_INTERFACES_NSIREQUEST_GETSTATUS 32887
#define ID_INTERFACES_NSIREQUEST_CANCEL 32888
#define ID_INTERFACES_NSIREQUEST_SUSPEND 32889
#define ID_INTERFACES_NSIREQUEST_RESUME 32890
#define ID_INTERFACES_NSIREQUEST_GETLOADGROUP 32891
#define ID_INTERFACES_NSIREQUEST_SETLOADGROUP 32892
#define ID_INTERFACES_NSIREQUEST_GETLOADFLAGS 32893
#define ID_INTERFACES_NSIREQUEST_SETLOADFLAGS 32894
#define ID_INTERFACES_NSIWEBNAV_GETCANGOBACK 32895
#define ID_INTERFACES_NSIWEBNAV_GETCANGOFORWARD 32896
#define ID_INTERFACES_NSIWEBNAV_GOBACK  32897
#define ID_INTERFACES_NSIWEBNAV_GOFORWARD 32898
#define ID_INTERFACES_NSIWEBNAV_GOTOINDEX 32899
#define ID_INTERFACES_NSIWEBNAV_LOADURI 32900
#define ID_INTERFACES_NSIWEBNAV_RELOAD  32901
#define ID_INTERFACES_NSIWEBNAV_STOP    32902
#define ID_INTERFACES_NSIWEBNAV_GETDOCUMENT 32903
#define ID_INTERFACES_NSIWEBNAV_GETCURRENTURI 32904
#define ID_INTERFACES_NSIWEBNAV_GETSESSIONHISTORY 32905
#define ID_INTERFACES_NSIWEBNAV_SETSESSIONHISTORY 32906
#define ID_INTERFACES_NSIWEBNAV_RUNALLTESTS 32907
#define ID_INTERFACES_NSIREQUEST_RUNALLTESTS 32908
#define ID_INTERFACES_NSIDOMWINDOW_GETTEXTZOOM 32910
#define ID_INTERFACES_NSIDOMWINDOW_SETTEXTZOOM 32911
#define ID_INTERFACES_NSICLIPBOARDCOMMANDS_PASTE 32912
#define ID_INTERFACES_NSICLIPBOARDCOMMANDS_COPYSELECTION 32913
#define ID_INTERFACES_NSICLIPBOARDCOMMANDS_SELECTALL 32914
#define ID_INTERFACES_NSICLIPBOARDCOMMANDS_SELECTNONE 32915
#define ID_INTERFACES_NSICLIPBOARDCOMMANDS_CUTSELECTION 32916
#define ID_INTERFACES_NSICLIPBOARDCOMMANDS_COPYLINKLOCATION 32917
#define ID_INTERFACES_NSICLIPBOARDCOMMANDS_CANCOPYSELECTION 32918
#define ID_INTERFACES_NSICLIPBOARDCOMMANDS_CANCUTSELECTION 32919
#define ID_INTERFACES_NSICLIPBOARDCOMMANDS_CANPASTE 32920
#define ID_CLIPBOARDCMD_PASTE           42789
#define ID_CLIPBOARDCMD_COPYSELECTION   42790
#define ID_CLIPBOARDCMD_SELECTALL       42791
#define ID_CLIPBOARDCMD_SELECTNONE      42792
#define ID_CLIPBOARDCMD_CUTSELECTION    42793
#define ID_CLIPBOARDCMD_COPYLINKLOCATION 42794
#define ID_CLIPBOARDCMD_CANCOPYSELECTION 42795
#define ID_CLIPBOARDCMD_CANCUTSELECTION 42796
#define ID_CLIPBOARDCMD_CANPASTE        42797

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_3D_CONTROLS                     1
#define _APS_NEXT_RESOURCE_VALUE        146
#define _APS_NEXT_COMMAND_VALUE         32921
#define _APS_NEXT_CONTROL_VALUE         1025
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif

==> mozilla_1.0.0.orig.tar.gz: mozilla/embedding/qa/testembed/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by testembed.rc
//
#define IDD_ABOUTBOX                    100
#define IDR_MAINFRAME                   128
#define IDR_MOZEMBTYPE                  129
#define IDR_CTXMENU_DOCUMENT            130
#define IDR_CTXMENU_LINK                131
#define IDR_CTXMENU_TEXT                132
#define IDR_CTXMENU_IMAGE               133
#define IDD_PROMPT_DIALOG               134
#define IDD_PROMPT_PASSWORD_DIALOG      135
#define IDD_PROMPT_USERPASS_DIALOG      136
#define IDD_PROFILES                    137
#define IDD_PROFILE_NEW                 138
#define IDD_PROFILE_RENAME              139
#define IDD_FINDDLG                     140
#define IDD_PRINT_PROGRESS_DIALOG       141
#define IDD_PREFS_START_PAGE            142
#define IDD_URLDIALOG                   144
#define IDD_DIALOG1                     145
#define IDD_RUNTESTSDLG                 145
#define ID_URL_BAR                      1001
#define ID_PROG_BAR                     1002
#define IDC_PROMPT_ANSWER               1003
#define IDC_PROMPT_QUESTION             1004
#define IDC_PROMPT_TEXT                 1005
#define IDC_USERNAME                    1006
#define IDC_PASSWORD                    1007
#define IDC_CHECK_SAVE_PASSWORD         1008
#define IDC_USERNAME_LABEL              1009
#define IDC_PASSWORD_LABEL              1010
#define IDC_LIST1                       1011
#define IDC_PROF_RENAME                 1012
#define IDC_PROF_DELETE                 1013
#define IDC_PROF_NEW                    1014
#define IDC_CHECK_ASK_AT_START          1015
#define IDC_NEW_PROF_NAME               1016
#define IDC_LOCALE_COMBO                1017
#define IDC_NEW_NAME                    1018
#define IDC_PPD_DOC_TXT                 1020
#define IDC_PPD_DOC_TITLE_STATIC        1021
#define IDC_ENTER_URLTEXT               1022
#define IDC_URLFIELD                    1023
#define IDC_MATCH_WHOLE_WORD            1040
#define IDC_MATCH_CASE                  1041
#define IDC_WRAP_AROUND                 1042
#define IDC_SEARCH_BACKWARDS            1043
#define IDC_FIND_EDIT                   1152
#define IDC_RADIO_BLANK_PAGE            1153
#define IDC_RADIO_HOME_PAGE             1154
#define IDC_EDIT_HOMEPAGE               1155
#define ID_NAV_BACK                     32773
#define ID_NAV_FORWARD                  32774
#define ID_NAV_HOME                     32775
#define ID_NAV_STOP                     32776
#define ID_NAV_RELOAD                   32777
#define ID_EDIT_SELECT_NONE             32778
#define ID_NEW_BROWSER                  32779
#define ID_VIEW_SOURCE                  32780
#define ID_VIEW_INFO                    32781
#define ID_VIEW_IMAGE                   32782
#define ID_OPEN_LINK_IN_NEW_WINDOW      32783
#define ID_SAVE_LINK_AS                 32784
#define ID_SAVE_IMAGE_AS                32785
#define ID_COPY_LINK_LOCATION           32786
#define ID_MANAGE_PROFILES              32787
#define ID_EDIT_PREFERENCES             32788
#define ID_TESTS_CHANGEURL              32789
#define ID_TESTS_GLOBALHISTORY          32790
#define ID_TOOLS_REMOVEGHPAGE           32791
#define ID_TESTS_CREATEFILE             32792
#define ID_INTERFACES_NSIFILE           32793
#define ID_TESTS_CREATEPROFILE          32794
#define ID_INTERFACES_NSISHISTORY       32795
#define ID_VERIFYBUGS_70228             32796
#define ID_TOOLS_REMOVEALLGH            32797
#define ID_TESTS_ADDWEBPROGLISTENER     32798
#define ID_TESTS_ADDHISTORYLISTENER     32799
#define ID_INTERFACES_NSIWEBNAV         32800
#define ID_TOOLS_TESTYOURMETHOD         32801
#define ID_TOOLS_TESTYOURMETHOD2        32802
#define ID_INTERFACES_NSIREQUEST        32803
#define ID_INTERFACES_TEMP              32804
#define ID_INTERFACES_NSIDOMWINDOW_RUNALLTESTS 32808
#define ID_INTERFACES_NSIDOMWINDOW_GETDOMDOCUMENT 32809
#define ID_INTERFACES_NSIDOMWINDOW_GETPARENT 32810
#define ID_INTERFACES_NSIDOMWINDOW_GETSCROLLBARS 32811
#define ID_INTERFACES_NSIDOMWINDOW_GETFRAMES 32812
#define ID_INTERFACES_NSIDOMWINDOW_GETNAME 32813
#define ID_INTERFACES_NSIDOMWINDOW_GETSCSOLLX 32814
#define ID_INTERFACES_NSIDOMWINDOW_GETSCROLLY 32815
#define ID_INTERFACES_NSIDOMWINDOW_SCROLLTO 32816
#define ID_INTERFACES_NSIDOMWINDOW_SCROLLBY 32817
#define ID_INTERFACES_NSIDOMWINDOW_GETSELECTION 32818
#define ID_INTERFACES_NSIDOMWINDOW_SCROLLBYLINES 32819
#define ID_INTERFACES_NSIDOMWINDOW_SCROLLBYPAGES 32820
#define ID_INTERFACES_NSIDOMWINDOW_SIZETOCONTENT 32821
#define ID_INTERFACES_NSIDIRECTORYSERVICE_RUNALLTESTS 32826
#define ID_INTERFACES_NSIDIRECTORYSERVICE_INIT 32827
#define ID_INTERFACES_NSIDIRECTORYSERVICE_REGISTERPROVIDER 32828
#define ID_INTERFACES_NSIDIRECTORYSERVICE_UNREGISTERPROVIDER 32829
#define ID_INTERFACES_NSISELECTION_RUNALLTESTS 32832
#define ID_VERIFYBUGS_90195             32833
#define ID_INTERFACES_CALLBACKS_NSISTREAMLISTENER 32834
#define ID_INTERFACES_CALLBACKS_NSIREQUESTOBSERVER 32835
#define ID_INTERFACES_CALLBACKS_NSISTREAMOBSERVER 32836
#define ID_INTERFACES_NSISELECTION_GETANCHORNODE 32837
#define ID_INTERFACES_NSISELECTION_GETANCHOROFFSET 32838
#define ID_INTERFACES_NSISELECTION_GETFOCUSNODE 32839
#define ID_INTERFACES_NSISELECTION_GETFOCUSOFFSET 32840
#define ID_INTERFACES_NSISELECTION_GETISCOLLAPSED 32841
#define ID_INTERFACES_NSISELECTION_GETRANGECOUNT 32842
#define ID_INTERFACES_NSISELECTION_GETRANGEAT 32843
#define ID_INTERFACES_NSISELECTION_COLLAPSE 32844
#define ID_INTERFACES_NSISELECTION_EXTEND 32845
#define ID_INTERFACES_NSISELECTION_COLLAPSETOSTART 32846
#define ID_INTERFACES_NSISELECTION_COLLAPSETOEND 32847
#define ID_INTERFACES_NSISELECTION_CONTAINSNODE 32848
#define ID_INTERFACES_NSISELECTION_SELECTALLCHILDREN 32849
#define ID_INTERFACES_NSISELECTION_ADDRANGE 32850
#define ID_INTERFACES_NSISELECTION_REMOVERANGE 32851
#define ID_INTERFACES_NSISELECTION_REMOVEALLRANGES 32852
#define ID_INTERFACES_NSISELECTION_DELETEFROMDOCUMENT 32853
#define ID_INTERFACES_NSISELECTION_SELECTIONLANGUAGECHANGE 32854
#define ID_INTERFACES_NSISELECTION_TOSTRING 32855
#define ID_INTERFACES_NSISELECTION_A    32857
#define ID_INTERFACES_NSIPROFILE_RUNALLTESTS 32858
#define ID_INTERFACES_NSIPROFILE_GETPROFILECOUNT 32859
#define ID_INTERFACES_NSIPROFILE_GETCURRENTPROFILE 32860
#define ID_INTERFACES_NSIPROFILE_SETCURRENTPROFILE 32861
#define ID_INTERFACES_NSIPROFILE_GETPROFILELIST 32862
#define ID_INTERFACES_NSIPROFILE_PROFILEEXISTS 32863
#define ID_INTERFACES_NSIPROFILE_CREATENEWPROFILE 32864
#define ID_INTERFACES_NSIPROFILE_RENAMEPROFILE 32865
#define ID_INTERFACES_NSIPROFILE_DELETEPROFILE 32866
#define ID_INTERFACES_NSIPROFILE_CLONEPROFILE 32867
#define ID_INTERFACES_NSIPROFILE_SHUTDOWNCURRENTPROFILE 32868
#define ID_INTERFACES_NSISHISTORY_GETCOUNT 32870
#define ID_INTERFACES_NSISHISTORY_GETINDEX 32871
#define ID_INTERFACES_NSISHISTORY_GETMAXLENGTH 32872
#define ID_INTERFACES_NSISHISTORY_SETMAXLENGTH 32873
#define ID_INTERFACES_NSISHISTORY_GETENTRYATINDEX 32874
#define ID_INTERFACES_NSISHISTORY_PURGEHISTORY 32875
#define ID_INTERFACES_NSISHISTORY_GETSHISTORYENUMERATOR 32878
#define ID_INTERFACES_NSISHISTORY_RUNALLTESTS 32879
#define ID_TESTS_REMOVEHISTORYLISTENER  32880
#define ID_INTERFACES_NSISHISTORY_NSIHISTORYENTRY_RUNALLTESTS 32881
#define ID_INTERFACES_NSISHISTORY_NSIHISTORYENTRY_GETURI 32882
#define ID_INTERFACES_NSISHISTORY_NSIHISTORYENTRY_GETTITLE 32883
#define ID_INTERFACES_NSISHISTORY_NSIHISTORYENTRY_GETISSUBFRAME 32884
#define ID_INTERFACES_NSIREQUEST_GETNAME 32885
#define ID_INTERFACES_NSIREQUEST_ISPENDING 32886
#define ID_INTERFACES_NSIREQUEST_GETSTATUS 32887
#define ID_INTERFACES_NSIREQUEST_CANCEL 32888
#define ID_INTERFACES_NSIREQUEST_SUSPEND 32889
#define ID_INTERFACES_NSIREQUEST_RESUME 32890
#define ID_INTERFACES_NSIREQUEST_GETLOADGROUP 32891
#define ID_INTERFACES_NSIREQUEST_SETLOADGROUP 32892
#define ID_INTERFACES_NSIREQUEST_GETLOADFLAGS 32893
#define ID_INTERFACES_NSIREQUEST_SETLOADFLAGS 32894
#define ID_INTERFACES_NSIWEBNAV_GETCANGOBACK 32895
#define ID_INTERFACES_NSIWEBNAV_GETCANGOFORWARD 32896
#define ID_INTERFACES_NSIWEBNAV_GOBACK  32897
#define ID_INTERFACES_NSIWEBNAV_GOFORWARD 32898
#define ID_INTERFACES_NSIWEBNAV_GOTOINDEX 32899
#define ID_INTERFACES_NSIWEBNAV_LOADURI 32900
#define ID_INTERFACES_NSIWEBNAV_RELOAD  32901
#define ID_INTERFACES_NSIWEBNAV_STOP    32902
#define ID_INTERFACES_NSIWEBNAV_GETDOCUMENT 32903
#define ID_INTERFACES_NSIWEBNAV_GETCURRENTURI 32904
#define ID_INTERFACES_NSIWEBNAV_GETSESSIONHISTORY 32905
#define ID_INTERFACES_NSIWEBNAV_SETSESSIONHISTORY 32906
#define ID_INTERFACES_NSIWEBNAV_RUNALLTESTS 32907
#define ID_INTERFACES_NSIREQUEST_RUNALLTESTS 32908
#define ID_INTERFACES_NSIDOMWINDOW_GETTEXTZOOM 32910
#define ID_INTERFACES_NSIDOMWINDOW_SETTEXTZOOM 32911
#define ID_INTERFACES_NSICLIPBOARDCOMMANDS_PASTE 32912
#define ID_INTERFACES_NSICLIPBOARDCOMMANDS_COPYSELECTION 32913
#define ID_INTERFACES_NSICLIPBOARDCOMMANDS_SELECTALL 32914
#define ID_INTERFACES_NSICLIPBOARDCOMMANDS_SELECTNONE 32915
#define ID_INTERFACES_NSICLIPBOARDCOMMANDS_CUTSELECTION 32916
#define ID_INTERFACES_NSICLIPBOARDCOMMANDS_COPYLINKLOCATION 32917
#define ID_INTERFACES_NSICLIPBOARDCOMMANDS_CANCOPYSELECTION 32918
#define ID_INTERFACES_NSICLIPBOARDCOMMANDS_CANCUTSELECTION 32919
#define ID_INTERFACES_NSICLIPBOARDCOMMANDS_CANPASTE 32920
#define ID_INTERFACES_NSIOBSERVERSERVICE_RUNALLTESTS 32922
#define ID_INTERFACES_NSIOBSERVERSERVICE_ADDOBSERVERS 32923
#define ID_INTERFACES_NSIOBSERVERSERVICE_ENUMERATEOBSERVERS 32924
#define ID_INTERFACES_NSIOBSERVERSERVICE_NOTIFYOBSERVERS 32925
#define ID_INTERFACES_NSIOBSERVERSERVICE_REMOVEOBSERVERS 32926
#define ID_INTERFACES_NSIFILE_INITWITHPATH 32927
#define ID_INTERFACES_NSIFILE_APPENDRELATICEPATH 32928
#define ID_INTERFACES_NSIFILE_EXISTS    32929
#define ID_INTERFACES_NSIFILE_CREATE    32930
#define ID_INTERFACES_NSIFILE_COPYTO    32931
#define ID_INTERFACES_NSIFILE_MOVETO    32932
#define ID_INTERFACES_NSIFILE_RUNALLTESTS 32933
#define ID_CLIPBOARDCMD_PASTE           42789
#define ID_CLIPBOARDCMD_COPYSELECTION   42790
#define ID_CLIPBOARDCMD_SELECTALL       42791
#define ID_CLIPBOARDCMD_SELECTNONE      42792
#define ID_CLIPBOARDCMD_CUTSELECTION    42793
#define ID_CLIPBOARDCMD_COPYLINKLOCATION 42794
#define ID_CLIPBOARDCMD_CANCOPYSELECTION 42795
#define ID_CLIPBOARDCMD_CANCUTSELECTION 42796
#define ID_CLIPBOARDCMD_CANPASTE        42797

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_3D_CONTROLS                     1
#define _APS_NEXT_RESOURCE_VALUE        146
#define _APS_NEXT_COMMAND_VALUE         32934
#define _APS_NEXT_CONTROL_VALUE         1025
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif
